AudioFocus class

Minimal audio focus helper (Android) and iOS ducking via flutter_tts. On Android, uses a small platform channel to request/abandon focus.

Constructors

AudioFocus()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

abandon() Future<void>
request() Future<bool>