CameraPosition class

Initial camera setup for the map.

Constructors

CameraPosition({required LatLng target, double zoom = 14, double tilt = 0, double bearing = 0})
Creates a camera positioned at target and zoom level (default 14).
const

Properties

bearing double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target LatLng
final
tilt double
final
zoom double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes to the map format expected by the native layers.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited