DirectionStep class

Constructors

DirectionStep({required LatLng startLocation, required LatLng endLocation, required int distanceMeters, required String instructionHtml, String? maneuver})
const

Properties

distanceMeters int
final
endLocation LatLng
final
hashCode int
The hash code for this object.
no setterinherited
instructionHtml String
final
instructionText String
no setter
maneuver String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startLocation LatLng
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited