DirectionsRoute class

Constructors

DirectionsRoute({required List<LatLng> points, required LatLng northeast, required LatLng southwest, required List<DirectionStep> steps, int? durationSeconds})
const

Properties

durationSeconds int?
final
hashCode int
The hash code for this object.
no setterinherited
northeast LatLng
final
points List<LatLng>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
southwest LatLng
final
steps List<DirectionStep>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited