MapPadding class

Padding to be applied around the map viewport (in logical pixels).

Constructors

MapPadding({double left = 0, double top = 0, double right = 0, double bottom = 0})
Creates padding with left, top, right, bottom.
const

Properties

bottom double
final
hashCode int
The hash code for this object.
no setterinherited
left double
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, double>
Serializes to the map format expected by the native layers.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited