MapStyleBuilder class

Helpers to build Google Maps JSON styles.

Constructors

MapStyleBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tinted(Color color, {bool dark = false}) String
Creates a simple single-color tinted map style based on color. If dark is true, uses darker contrasts for better readability at night.