MarkerOptions class

Marker configuration.

Constructors

MarkerOptions({required String id, required LatLng position, String? title, String? snippet, String? iconUrl, double? iconDp, double anchorU = 0.5, double anchorV = 0.62, double rotation = 0, bool draggable = false, double zIndex = 0})
Creates marker options. id must be unique.
const

Properties

anchorU double
final
anchorV double
final
draggable bool
final
hashCode int
The hash code for this object.
no setterinherited
iconDp double?
final
iconUrl String?
final
id String
final
position LatLng
final
rotation double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snippet String?
final
title String?
final
zIndex double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes to the map format expected by the native layers.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited