NavUiOptions class

Minimal options to launch the native Google Navigation UI (when available).

Note: This requires access to the Google Maps Navigation SDK on Android/iOS. If not available, the native side will return an error or present a placeholder.

Constructors

const

Properties

apiKey String
final
colorOnPrimary Color?
final
colorOnSurface Color?
final
colorPrimary Color?
final
colorSurface Color?
final
destination LatLng
final
hashCode int
The hash code for this object.
no setterinherited
intermediates List<Waypoint>
final
languageCode String
final
mapId String?
final
origin LatLng
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeMode NavUiThemeMode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited