NavigationOptions class

Constructors

const

Properties

androidRequestAudioFocus bool
final
apiKey String
final
approachSpeakMeters List<double>
final
arrivalThresholdMeters double
final
cameraTilt double
final
cameraZoom double
final
destination LatLng
final
followBearing bool
final
hashCode int
The hash code for this object.
no setterinherited
headingFilterAlpha double
final
intermediates List<Waypoint>
final
interruptOnNewInstruction bool
final
iosDuckOthers bool
final
language String
final
lowSpeedAutoRotateKmh double
final
mapMatchingToleranceMeters double
final
minTimeBetweenReroutes Duration
final
mode String
final
offRouteThresholdMeters double
final
origin LatLng
final
rerouteOnOffRoute bool
final
routeColor Color?
final
routeWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showVehicleMarker bool
final
simulationSpeedKmh double?
final
snapToRoute bool
final
speedAlertsEnabled bool
final
speedLimitKmh double?
final
speedLimitProvider SpeedLimitProvider?
final
ttsPitch double
final
ttsRate double
final
ttsVoice String?
final
useDeviceHeading bool
final
useRoutesV2 bool
final
vehicleIconAnchorU double
final
vehicleIconAnchorV double
final
vehicleIconDp double
final
vehicleIconUrl String?
final
vehicleMarkerId String
final
vehicleRotationSource VehicleRotationSource
final
voiceAheadDistanceMeters double
final
voiceGuidance bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited