NavigationUi class

Bridge to the native Navigation UI host.

Constructors

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isAvailable() Future<bool>
Returns whether the native Navigation SDK is available on this platform.
start(NavUiOptions options) Future<bool>
Launches the native Navigation UI with options. Returns true if opened.
stop() Future<void>
Closes the native Navigation UI if it is currently presented.