PolylineOptions class

Polyline configuration.

Constructors

PolylineOptions({required String id, required List<LatLng> points, Color color = const Color(0xFF1B5E20), double width = 6, bool geodesic = false, bool dotted = false})
Creates polyline options. id must be unique.
const

Properties

color Color
final
dotted bool
final
geodesic bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
points List<LatLng>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes to the map format expected by the native layers.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited