RouteLegData class

Constructors

RouteLegData({int? distanceMeters, int? durationSeconds, List<RouteStepData> steps = const []})
const
RouteLegData.fromJson(Map<String, dynamic> json)
factory

Properties

distanceMeters int?
final
durationSeconds int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<RouteStepData>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited