RouteMatrixElement class

One origin/destination ETA entry from ComputeRouteMatrix.

Constructors

RouteMatrixElement({required int originIndex, required int destinationIndex, int? durationSeconds, int? distanceMeters, String? status})
const
RouteMatrixElement.fromJson(Map<String, dynamic> json)
factory

Properties

destinationIndex int
final
distanceMeters int?
final
durationSeconds int?
final
hashCode int
The hash code for this object.
no setterinherited
originIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited