RouteModifiers class
Route constraints (avoid tolls/highways/ferries) and toll passes.
Constructors
- RouteModifiers({bool avoidTolls = false, bool avoidHighways = false, bool avoidFerries = false})
-
const
Properties
- avoidFerries → bool
-
final
- avoidHighways → bool
-
final
- avoidTolls → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited