RouteStepData class

Constructors

RouteStepData({int? distanceMeters, List<LatLng> points = const [], String? instruction, String? maneuver})
const
RouteStepData.fromJson(Map<String, dynamic> json)
factory

Properties

distanceMeters int?
final
hashCode int
The hash code for this object.
no setterinherited
instruction String?
final
maneuver String?
final
points List<LatLng>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited