Waypoint class

Waypoint with advanced options.

Constructors

Waypoint({LatLng? location, String? placeId, bool? via, bool? sideOfRoad})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
location LatLng?
final
placeId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sideOfRoad bool?
final
via bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited