CameraPosition class
Initial camera setup for the map.
Constructors
- CameraPosition({required LatLng target, double zoom = 14, double tilt = 0, double bearing = 0})
-
Creates a camera positioned at
targetandzoomlevel (default 14).const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Serializes to the map format expected by the native layers.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited