DeviceHeading class
Device heading (compass/rotation vector) broadcast stream.
Values are degrees [0,360), where 0 = North, 90 = East. On iOS uses Core Location heading; on Android uses TYPE_ROTATION_VECTOR.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited