GmnsNavHub class
Minimal helper hub to make it easier to use from FlutterFlow custom actions. Holds a single active controller/session and exposes simple methods.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- activeRouteIndex → int?
-
no setter
- controller → GoogleMapController?
-
no setter
- lastRoutes → RoutesResponse?
-
no setter
- session → NavigationSession?
-
no setter
Static Methods
-
chooseActiveRoute(
int index) → Future< void> - Switches visual active route among those drawn by computeRoutesAndDraw.
-
computeRoutesAndDraw(
{required String apiKey, required LatLng origin, required LatLng destination, List< Waypoint> intermediates = const [], RouteModifiers? modifiers, bool alternatives = true, Units units = Units.metric, String languageCode = 'pt-BR', PolylineQuality polylineQuality = PolylineQuality.high, int activeIndex = 0}) → Future<int> - Computes routes, draws all alternatives as separate polylines, and selects one as active. Returns the number of routes.
-
overview(
) → Future< void> -
recenter(
) → Future< void> -
setController(
GoogleMapController controller) → void -
Starts TBT navigation to
destinationfromoriginusing Directions (lightweight).