NavigationSession class
Properties
- controller → GoogleMapController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPaused → bool
-
no setter
- isSimulating → bool
-
no setter
-
onInstruction
→ Stream<
NavInstruction> -
no setter
-
onProgress
→ Stream<
NavProgress> -
no setter
-
onSpeedAlert
→ Stream<
SpeedAlert> -
no setter
-
onState
→ Stream<
NavState> -
no setter
- options → NavigationOptions
-
final
- polylineId → String
-
final
- route → DirectionsRoute
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simulationSpeedKmh → double
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overview(
) → Future< void> -
pause(
) → Future< void> -
recenter(
) → Future< void> -
resume(
) → Future< void> -
setSimulationSpeed(
double kmh) → Future< void> -
stop(
{bool clearRoute = true}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited