RouteData class
Route data with polyline, distance, duration, toll info and details.
Constructors
-
RouteData({required int index, required List<
LatLng> points, int? distanceMeters, int? durationSeconds, int? staticDurationSeconds, TollInfo? tollInfo, LatLng? northeast, LatLng? southwest, List<RouteLegData> legs = const [], List<String> routeLabels = const []}) -
const
-
RouteData.fromJson(Map<
String, dynamic> json, {required int index}) -
factory
Properties
- distanceMeters → int?
-
final
- durationSeconds → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
-
legs
→ List<
RouteLegData> -
final
- northeast → LatLng?
-
final
-
points
→ List<
LatLng> -
final
-
routeLabels
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- southwest → LatLng?
-
final
- staticDurationSeconds → int?
-
final
- tollInfo → TollInfo?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited