GoogleMapsNativeSdkPlatform class abstract
Platform interface for google_maps_native_sdk.
Allows alternative implementations to provide the platform version and other platform-specific functionality. The default uses a method channel.
- Inheritance
-
- Object
- PlatformInterface
- GoogleMapsNativeSdkPlatform
- Implementers
Constructors
- GoogleMapsNativeSdkPlatform()
- Constructs a GoogleMapsNativeSdkPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> - Returns the platform version string from the host platform.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ GoogleMapsNativeSdkPlatform
-
The default instance of GoogleMapsNativeSdkPlatform to use.
getter/setter pair